@@ -31,9 +31,9 @@ globalVariables(c("y", "N", "Z", "Bound", "thetaidx", "Probability", "delta", "A
 #' are used. For a \code{gsDesign} object where \code{theta} is input as
 #' \code{NULL} (the default), \code{theta=seq(0,2,.05)*x$delta}) is used.  For
 #' a \code{gsDesign} object, the x-axis values are rescaled to
-#' \code{theta/x$delta} and the label for the x-axis \eqn{theta / delta}. For a
+#' \code{theta/x$delta} and the label for the x-axis \eqn{\theta / \delta}. For a
 #' \code{gsProbability} object, the values of \code{theta} are plotted and are
-#' labeled as \eqn{theta}. See examples below.
+#' labeled as \eqn{\theta}. See examples below.
 #'
 #' Approximate treatment effects at boundaries are computed dividing the Z-values
 #' at the boundaries by the square root of \code{n.I} at that analysis.
@@ -57,7 +57,7 @@ globalVariables(c("y", "N", "Z", "Bound", "thetaidx", "Probability", "delta", "A
 #'
 #' B-values are Z-values multiplied by \code{sqrt(t)=sqrt(x$n.I/x$n.I[x$k])}.
 #' Thus, the expected value of a B-value at an analysis is the true value of
-#' \eqn{theta} multiplied by the proportion of total planned observations at
+#' \eqn{\theta} multiplied by the proportion of total planned observations at
 #' that time. See Proschan, Lan and Wittes (2006).
 #'
 #' @param x Object of class \code{gsDesign} for \code{plot.gsDesign()} or
@@ -323,7 +323,7 @@ gsCPz <- function(z, i, x, theta = NULL, ylab = NULL, ...) {
 # qplotit roxy [sinew] ----
 #' @importFrom graphics lines text
 #' @importFrom ggplot2 ggplot aes geom_text geom_line scale_x_continuous scale_y_continuous scale_colour_manual scale_linetype_manual ggtitle xlab ylab
-#' @importFrom rlang !! sym
+#' @importFrom rlang .data
 # qplotit function [sinew] ----
 qplotit <- function(x, xlim = NULL, ylim = NULL, main = NULL, geom = c("line", "text"),
                     dgt = c(2, 2), lty = c(2, 1), col = c(1, 1),
@@ -398,8 +398,8 @@ qplotit <- function(x, xlim = NULL, ylim = NULL, main = NULL, geom = c("line", "
     lbls <- c("Lower", "Upper")
     if (x$test.type > 1) {
       p <- ggplot2::ggplot(data = y, ggplot2::aes(
-        x = as.numeric(!!rlang::sym('N')), y = as.numeric(!!rlang::sym('Z')), group = factor(!!rlang::sym('Bound')),
-        col = factor(!!rlang::sym('Bound')), label = Ztxt, lty = factor(!!rlang::sym('Bound'))
+        x = as.numeric(.data$N), y = as.numeric(.data$Z), group = factor(.data$Bound),
+        col = factor(.data$Bound), label = Ztxt, lty = factor(.data$Bound)
       )) + 
         ggplot2::geom_text(show.legend = F, size = cex * 5) + 
         ggplot2::geom_line() +
@@ -412,10 +412,10 @@ qplotit <- function(x, xlim = NULL, ylim = NULL, main = NULL, geom = c("line", "
 
     } else {
       p <- ggplot2::ggplot(ggplot2::aes(
-        x = as.numeric(!!rlang::sym('N')),
-        y = as.numeric(!!rlang::sym('Z')),
+        x = as.numeric(.data$N),
+        y = as.numeric(.data$Z),
         label = Ztxt, 
-        group = factor(!!rlang::sym('Bound'))),
+        group = factor(.data$Bound)),
         data = y
         ) +
         ggplot2::geom_line(colour = getColor(col[1]), lty = lty[1], lwd = lwd[1]) +
@@ -441,14 +441,14 @@ qplotit <- function(x, xlim = NULL, ylim = NULL, main = NULL, geom = c("line", "
         graphics::text(x = y2$N, y = y2$Z, paste(rep("r=", x$k), y2$Ztxt, sep = ""), cex = cex)
       } else {
         y2$Ztxt <- paste(rep("r=", x$k), y2$Ztxt, sep = "")
-        p <- p + geom_text(data = y2, aes(group = factor(!!rlang::sym('Bound')), label = Ztxt), size = cex * 5, show.legend = F, colour = getColor(1))
+        p <- p + geom_text(data = y2, aes(group = factor(.data$Bound), label = Ztxt), size = cex * 5, show.legend = F, colour = getColor(1))
       }
     } else {
       if (base) {
         graphics::text(x = y2$N, y = y2$Z, paste(rep("N=", x$k), y2$Ztxt, sep = ""), cex = cex)
       } else {
         y2$Ztxt <- paste(rep("N=", x$k), y2$Ztxt, sep = "")
-        p <- p + ggplot2::geom_text(data = y2, ggplot2::aes(group = factor(!!rlang::sym('Bound')), label = Ztxt), size = cex * 5, show.legend = F, colour = getColor(1))
+        p <- p + ggplot2::geom_text(data = y2, ggplot2::aes(group = factor(.data$Bound), label = Ztxt), size = cex * 5, show.legend = F, colour = getColor(1))
       }
     }
   }
@@ -741,7 +741,7 @@ plotsf <- function(x,
 # plotASN roxy [sinew] ----
 #' @importFrom graphics plot
 #' @importFrom ggplot2 qplot
-#' @importFrom rlang !! sym
+#' @importFrom rlang .data
 # plotASN function [sinew] ----
 plotASN <- function(x, xlab = NULL, ylab = NULL, main = NULL, theta = NULL, xval = NULL, type = "l",
                     base = FALSE, ...) {
@@ -808,17 +808,29 @@ plotASN <- function(x, xlab = NULL, ylab = NULL, main = NULL, theta = NULL, xval
 
 # plotgsPower roxy [sinew] ----
 #' @importFrom stats reshape
-#' @importFrom dplyr group_by summarise
+#' @importFrom dplyr group_by reframe
 #' @importFrom ggplot2 ggplot aes geom_line ylab guides guide_legend xlab scale_linetype_manual scale_color_manual scale_y_continuous ggtitle scale_x_continuous scale_colour_manual geom_text
-#' @importFrom rlang !! sym
+#' @importFrom rlang .data
 #' @importFrom graphics plot axis lines strwidth text
+#' @param offset Integer to offset the numeric labels of the "Analysis" legend
+#'   (default: 0). Only relevant for \code{outtype = 1}. By default will change
+#'   legend title to "Future Analysis". To customize the title, pass the label
+#'   to the argument \code{titleAnalysisLegend}
+#' @param titleAnalysisLegend Label to use as the title for the "Analysis"
+#'   legend (default: NULL)
 # plotgsPower function [sinew] ----
 plotgsPower <- function(x, main = "Boundary crossing probabilities by effect size",
                         ylab = "Cumulative Boundary Crossing Probability",
                         xlab = NULL, lty = NULL, col = NULL, lwd = 1, cex = 1,
                         theta = if (inherits(x, "gsDesign")) seq(0, 2, .05) * x$delta else x$theta,
-                        xval = NULL, base = FALSE, outtype = 1, ...) {
+                        xval = NULL, base = FALSE, outtype = 1, offset = 0,
+                        titleAnalysisLegend = NULL, ...) {
 
+  stopifnot(
+    is.numeric(offset) && length(offset) == 1,
+    is.null(titleAnalysisLegend) ||
+      (is.character(titleAnalysisLegend) && length(titleAnalysisLegend) == 1)
+  )
   if (is.null(xval)) {
     if (inherits(x, "gsDesign")) {
       xval <- x$delta0 + (x$delta1 - x$delta0) * theta / x$delta
@@ -856,30 +868,39 @@ plotgsPower <- function(x, main = "Boundary crossing probabilities by effect siz
     
     y2 <- y %>%
              dplyr::group_by(Bound, thetaidx) %>% 
-             dplyr::summarise(Probability = cumsum(Probability))
+             dplyr::reframe(Probability = cumsum(Probability))
     
     y2$Probability[y2$Bound == "1-Lower bound"] <- 1 - y2$Probability[y2$Bound == "1-Lower bound"]
     
-    y2$Analysis <- factor(y$id)
+    y2$Analysis <- factor(y$id + offset)
     
+    # Determine title of Analysis legend
+    titleAnalysis <- "Analysis"
+    if (offset > 0) {
+      titleAnalysis <- "Future Analysis"
+    }
+    if (!is.null(titleAnalysisLegend)) {
+      titleAnalysis <- titleAnalysisLegend
+    }
+
     y2$delta <- xval[y$thetaidx]
     
     p <- ggplot2::ggplot(y2, 
                          ggplot2::aes(
-                           x = !!rlang::sym('delta'), 
-                           y = !!rlang::sym('Probability'), 
-                           col = !!rlang::sym('Bound'), 
-                           lty = !!rlang::sym('Analysis'))
+                           x = .data$delta,
+                           y = .data$Probability,
+                           col = .data$Bound,
+                           lty = .data$Analysis)
                          ) + 
       ggplot2::geom_line(size = lwd) + 
       ggplot2::ylab(ylab) +
       ggplot2::guides(color = ggplot2::guide_legend(title = "Probability")) + 
       ggplot2::xlab(xlab) +
-      ggplot2::scale_linetype_manual(values = lty) +
+      ggplot2::scale_linetype_manual(values = lty, name = titleAnalysis) +
       ggplot2::scale_color_manual(values = getColor(col)) +
       ggplot2::scale_y_continuous(breaks = seq(0, 1, .2))
     
-      return(p + ggplot2::ggtitle(label = main))
+    return(p + ggplot2::ggtitle(label = main))
   }
   if (is.null(col)) {
     if (base || outtype == 2) {
